==> bayesAB_1.0.0.tar.gz: bayesAB/R/constructors.R <==
constructors <- function() {
  list(
    "bernoulli" = list(
      dataChecks = list(
        checkBinomialData
      ),
      priorChecks = list(
        checkBetaPriors
      ),
      posteriors = Bernoulli
    ),

    "bernoulliC" = list(
      dataChecks = list(
        checkBinomialData
      ),
      priorChecks = list(
        checkBetaPriors
      ),
      posteriors = BernoulliClosed
    ),

    "normal" = list(
      dataChecks = list(),
      priorChecks = list(
        checkNormalPriors,
        checkInvGammaPriors
      ),
      posteriors = Normal
    ),

    "lognormal" = list(
      dataChecks = list(
        checkPositiveData,
        checkNotZeroData
      ),
      priorChecks = list(
        checkNormalPriors,
        checkInvGammaPriors
      ),
      posteriors = LogNormal
    ),

    "poisson" = list(
      dataChecks = list(
        checkPositiveData,
        checkIntegerData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = Poisson
    ),

    "poissonC" = list(
      dataChecks = list(
        checkPositiveData,
        checkIntegerData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = PoissonClosed
    ),

    "exponential" = list(
      dataChecks = list(
        checkPositiveData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = Exponential
    ),

    "uniform" = list(
      dataChecks = list(
        checkPositiveData
      ),
      priorChecks = list(
        checkParetoPriors
      ),
      posteriors = Uniform
    )
  )
}

getDistribution <- function(distribution) constructors()[[distribution]]

==> bayesAB_1.1.3.tar.gz: bayesAB/R/constructors.R <==
constructors <- function() {
  list(
    "bernoulli" = list(
      prior = 'Beta',
      dataChecks = list(
        checkBinomialData
      ),
      priorChecks = list(
        checkBetaPriors
      ),
      posteriors = Bernoulli
    ),

    "bernoulliC" = list(
      prior = 'Beta',
      dataChecks = list(
        checkBinomialData
      ),
      priorChecks = list(
        checkBetaPriors
      ),
      posteriors = BernoulliClosed
    ),

    "normal" = list(
      prior = 'NormalInvGamma',
      dataChecks = list(),
      priorChecks = list(
        checkNormalInvGammaPriors
      ),
      posteriors = Normal
    ),

    "lognormal" = list(
      prior = 'NormalInvGamma',
      dataChecks = list(
        checkPositiveData,
        checkNotZeroData
      ),
      priorChecks = list(
        checkNormalInvGammaPriors
      ),
      posteriors = LogNormal
    ),

    "poisson" = list(
      prior = 'Gamma',
      dataChecks = list(
        checkPositiveData,
        checkIntegerData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = Poisson
    ),

    "poissonC" = list(
      prior = 'Gamma',
      dataChecks = list(
        checkPositiveData,
        checkIntegerData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = PoissonClosed
    ),

    "exponential" = list(
      prior = 'Gamma',
      dataChecks = list(
        checkPositiveData
      ),
      priorChecks = list(
        checkGammaPriors
      ),
      posteriors = Exponential
    ),

    "uniform" = list(
      prior = 'Pareto',
      dataChecks = list(
        checkPositiveData
      ),
      priorChecks = list(
        checkParetoPriors
      ),
      posteriors = Uniform
    )
  )
}

getDistribution <- function(distribution) constructors()[[distribution]]
